@@ -2,9 +2,8 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import stock
-from . import product
-from . import account
+
+from . import account, product, stock
 
 
 def register():
@@ -16,12 +15,6 @@ def register():
         product.Product,
         account.Configuration,
         account.ConfigurationStockJournal,
-        account.ConfigurationCostPriceCounterpartAccount,
         account.FiscalYear,
         account.AccountMove,
-        product.UpdateCostPriceAsk,
-        product.UpdateCostPriceShowMove,
         module='account_stock_continental', type_='model')
-    Pool.register(
-        product.UpdateCostPrice,
-        module='account_stock_continental', type_='wizard')
